===============================
gcloud-odm
===============================


.. image:: https://img.shields.io/pypi/v/gcloud_odm.svg
        :target: https://pypi.python.org/pypi/gcloud_odm

.. image:: https://img.shields.io/travis/fulfilio/gcloud_odm.svg
        :target: https://travis-ci.org/fulfilio/gcloud_odm

.. image:: https://readthedocs.org/projects/gcloud-odm/badge/?version=latest
        :target: https://gcloud-odm.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/fulfilio/gcloud_odm/shield.svg
     :target: https://pyup.io/repos/github/fulfilio/gcloud_odm/
     :alt: Updates


Google cloud datastore based ODM


* Free software: BSD license
* Documentation: https://gcloud-odm.readthedocs.io.


Features
--------

* TODO

Credits
---------

Maintained by Fulfil.IO_

.. _Fulfil.IO: https://www.fulfil.io
